@@ -9,7 +9,6 @@
 #include <KDBusService>
 #include <KLocalizedString>
 #include <KSharedConfig>
-#include <Kdelibs4ConfigMigrator>
 #include <QApplication>
 #include <QCommandLineParser>
 #include <QDebug>
@@ -24,20 +23,14 @@
 
 int main(int argc, char *argv[])
 {
-    QCoreApplication::setAttribute(Qt::AA_UseHighDpiPixmaps, true);
-    QCoreApplication::setAttribute(Qt::AA_EnableHighDpiScaling, true);
     QApplication app(argc, argv);
     app.setQuitOnLastWindowClosed(false);
 
-    Kdelibs4ConfigMigrator migrate(QLatin1String("rsibreak"));
-    migrate.setConfigFiles(QStringList() << QLatin1String("rsibreakrc") << QLatin1String("rsibreak.notifyrc"));
-    migrate.migrate();
-
     KLocalizedString::setApplicationDomain("rsibreak");
 
     KAboutData aboutData("rsibreak",
                          i18n("RSIBreak"),
-                         "0.12.15",
+                         "0.13.0",
                          i18n("Try to prevent Repetitive Strain Injury by "
                               "reminding a user to rest."),
                          KAboutLicense::GPL,
@@ -51,6 +44,8 @@ int main(int argc, char *argv[])
 
     aboutData.setTranslator(i18nc("NAME OF TRANSLATORS", "Your names"), i18nc("EMAIL OF TRANSLATORS", "Your emails"));
 
+    QApplication::setWindowIcon(QIcon::fromTheme(QStringLiteral("rsibreak")));
+
     QCommandLineParser parser;
     KAboutData::setApplicationData(aboutData);
     parser.addOption(QCommandLineOption("autostart"));
