@@ -17,7 +17,9 @@
 #include <kconfig.h>
 #include <kconfiggroup.h>
 #include <ksharedconfig.h>
+#include <kwindowinfo.h>
 #include <kwindowsystem.h>
+#include <kx11extras.h>
 
 #include "rsiglobals.h"
 #include "rsistats.h"
@@ -65,7 +67,7 @@ void RSITimer::run()
 
 bool RSITimer::suppressionDetector()
 {
-    for (WId win : KWindowSystem::windows()) {
+    for (WId win : KX11Extras::windows()) {
         KWindowInfo info(win, NET::WMDesktop | NET::WMState | NET::XAWMState);
         if ((info.state() & NET::FullScreen) && !info.isMinimized() && info.isOnCurrentDesktop()) {
             return true;
@@ -83,6 +85,10 @@ void RSITimer::hibernationDetector(const int totalIdle)
         qDebug() << "Not been checking idleTime for more than 60 seconds, "
                  << "assuming the computer hibernated, resetting timers"
                  << "Last: " << last << "Current: " << current << "Idle, s: " << totalIdle;
+        m_bigBreakCounter->reset();
+        if (m_tinyBreakCounter) {
+            m_tinyBreakCounter->reset();
+        }
         resetAfterBreak();
     }
     last = current;
