@@ -18,6 +18,7 @@
 #include <QVBoxLayout>
 
 #include <KWindowSystem>
+#include <KX11Extras>
 
 SlideEffect::SlideEffect(QObject *parent)
     : BreakBase(parent)
@@ -29,11 +30,11 @@ SlideEffect::SlideEffect(QObject *parent)
     connect(qApp, &QGuiApplication::screenAdded, this, &SlideEffect::slotGray);
     connect(qApp, &QGuiApplication::screenRemoved, this, &SlideEffect::slotGray);
 
-    m_slidewidget = new SlideWidget(0);
-    KWindowSystem::forceActiveWindow(m_slidewidget->winId());
-    KWindowSystem::setOnAllDesktops(m_slidewidget->winId(), true);
-    KWindowSystem::setState(m_slidewidget->winId(), NET::KeepAbove);
-    KWindowSystem::setState(m_slidewidget->winId(), NET::FullScreen);
+    m_slidewidget = new SlideWidget(nullptr);
+    KX11Extras::forceActiveWindow(m_slidewidget->winId());
+    KX11Extras::setOnAllDesktops(m_slidewidget->winId(), true);
+    KX11Extras::setState(m_slidewidget->winId(), NET::KeepAbove);
+    KX11Extras::setState(m_slidewidget->winId(), NET::FullScreen);
 
     setReadOnly(true);
 
